import Button from '@material-ui/core/Button'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React, { useCallback } from 'react'
import './formNavigation.scss'

interface FormNavigationProps {
  handlePrevious: () => void
  handleNext: () => void
  disablePrevButton?: boolean
  disableNextButton: boolean
  isLastStep?: boolean
  isLoading?: boolean
}

const FormNavigation = ({
  handlePrevious,
  handleNext,
  disablePrevButton,
  disableNextButton,
  isLastStep,
  isLoading,
}: FormNavigationProps) => {
  const { t } = useI18n()

  const getSecondButtonLabel = useCallback(() => {
    if (isLoading) return t('profile_type.form.button_loading')
    if (isLastStep) return t('profile_type.form.button_end')
    return t('profile_type.form.button_next')
  }, [isLastStep, isLoading, t])

  return (
    <div className="profile-navigation">
      <Button
        aria-label={t('profile_type.accessibility.button_previous')}
        onClick={handlePrevious}
        className="btnSecondary"
        disabled={disablePrevButton}
      >
        {t('profile_type.form.button_previous')}
      </Button>
      <Button
        aria-label={
          isLastStep
            ? t('profile_type.accessibility.button_end')
            : t('profile_type.accessibility.button_next')
        }
        onClick={handleNext}
        className="btnPrimary"
        disabled={disableNextButton}
      >
        {getSecondButtonLabel()}
      </Button>
    </div>
  )
}

export default FormNavigation
