import { act, render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import EcogestureSelectionDetail from './EcogestureSelectionDetail'

const mockValidate = jest.fn()

describe('EcogestureSelectionDetail component', () => {
  it('should be rendered correctly', async () => {
    const { container } = render(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
  })

  describe('should click on buttons', () => {
    it('should toggle more details', async () => {
      render(
        <EcogestureSelectionDetail
          ecogesture={mockedEcogesturesData[0]}
          validate={mockValidate}
          title={mockedEcogesturesData[0].shortName}
        />
      )
      await act(async () => {
        await userEvent.click(screen.getByText('ecogesture_modal.show_more'))
      })
      expect(screen.getByText('ecogesture_modal.show_less')).toBeInTheDocument()
    })
    it('should call validate with objective to true', async () => {
      render(
        <EcogestureSelectionDetail
          ecogesture={mockedEcogesturesData[0]}
          validate={mockValidate}
          title={mockedEcogesturesData[0].shortName}
        />
      )
      await act(async () => {
        await userEvent.click(
          screen.getByText('ecogesture_selection.button_objective')
        )
      })
      expect(mockValidate).toHaveBeenCalledWith(true, false)
    })

    it('should call validate with doing to true', async () => {
      render(
        <EcogestureSelectionDetail
          ecogesture={mockedEcogesturesData[0]}
          validate={mockValidate}
          title={mockedEcogesturesData[0].shortName}
        />
      )
      await act(async () => {
        await userEvent.click(
          screen.getByText('ecogesture_selection.button_doing')
        )
      })
      expect(mockValidate).toHaveBeenCalledWith(false, true)
    })

    it('should call validate with objective and doing to false', async () => {
      render(
        <EcogestureSelectionDetail
          ecogesture={mockedEcogesturesData[0]}
          validate={mockValidate}
          title={mockedEcogesturesData[0].shortName}
        />
      )
      await act(async () => {
        await userEvent.click(
          screen.getByText('ecogesture_selection.button_skip')
        )
      })
      expect(mockValidate).toHaveBeenCalledWith(false, false)
    })
  })
})
