import { render, waitFor } from '@testing-library/react'
import React from 'react'
import { Provider } from 'react-redux'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureSelectionView from './EcogestureSelectionView'

const mockGetEcogestureListByProfile = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getEcogestureListByProfile: mockGetEcogestureListByProfile,
  }))
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionModal/EcogestureSelectionModal',
  () => 'mock-ecogestureSelectionModal'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionDetail/EcogestureSelectionDetail',
  () => 'mock-ecogestureSelectionDetail'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionRestart/EcogestureSelectionRestart',
  () => 'mock-ecogestureSelectionRestart'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionEnd/EcogestureSelectionEnd',
  () => 'mock-ecogestureSelectionEnd'
)

describe('EcogestureSelection component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([mockedEcogesturesData[0]])
    const { container } = render(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    expect(
      container.getElementsByTagName('mock-ecogestureSelectionModal')[0]
    ).toBeInTheDocument()
    expect(
      container.getElementsByTagName('mock-ecogestureSelectionDetail')[0]
    ).toBeInTheDocument()
  })

  it('should render with the EcogestureSelectionEnd', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([])
    const { container } = render(
      <Provider store={store}>
        <EcogestureSelectionView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(
      container.getElementsByTagName('mock-ecogestureSelectionEnd')[0]
    ).toBeInTheDocument()
  })
})
