import Button from '@material-ui/core/Button'
import { useClient } from 'cozy-client'
import { SUCCESS_EVENT } from 'cozy-harvest-lib/dist/models/flowEvents'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { KonnectorError } from 'enums'
import { Account } from 'models'
import React, { useCallback } from 'react'
import { useNavigate } from 'react-router-dom'
import AccountService from 'services/account.service'
import './konnectorModal.scss'

declare let __SAU_ISSUE_DIRECT_LINK__: string

interface KonnectorModalFooterProps {
  state: string | null
  error: KonnectorError | null
  handleCloseClick: (isSuccess?: boolean) => void
  handleAccountDeletion: () => Promise<void>
  account: Account | null
  isUpdating: boolean
}

const KonnectorModalFooter = ({
  state,
  error,
  handleCloseClick,
  handleAccountDeletion,
  account,
  isUpdating,
}: KonnectorModalFooterProps) => {
  const { t } = useI18n()
  const client = useClient()
  const navigate = useNavigate()

  const handleSGELoginRetry = () => {
    handleCloseClick(state === SUCCESS_EVENT)
    navigate('/connect/electricity')
  }

  const handleResetSGEAccount = useCallback(async () => {
    if (account) {
      const accountService = new AccountService(client)
      await accountService.deleteAccount(account)
      await handleAccountDeletion()
      navigate('/connect/electricity')
    }
  }, [account, client, handleAccountDeletion, navigate])

  if (error === KonnectorError.USER_ACTION_NEEDED) {
    // INSEE CODE ERROR ENEDIS
    return (
      <Button
        aria-label={t('konnector_modal.accessibility.button_close')}
        onClick={() => handleCloseClick(state === SUCCESS_EVENT)}
        className="btnPrimary"
      >
        <div>{t('konnector_modal.button_understood')}</div>
      </Button>
    )
  } else if (error === KonnectorError.LOGIN_FAILED) {
    // INCOMPLETE CONSENT FORM - GRDF // what is this comment ?
    return (
      <Button
        aria-label={t('konnector_modal.accessibility.button_close')}
        onClick={() => handleCloseClick(state === SUCCESS_EVENT)}
        className="btnPrimary"
      >
        <div>{t('konnector_modal.button_try_again')}</div>
      </Button>
    )
  } else if (error === KonnectorError.TERMS_VERSION_MISMATCH) {
    return (
      <div className="buttons">
        <Button
          aria-label={t('konnector_modal.accessibility.button_close')}
          onClick={() => handleCloseClick(state === SUCCESS_EVENT)}
          className="btnSecondary"
        >
          <div>{t('konnector_modal.button_later')}</div>
        </Button>
        <Button
          aria-label={t('konnector_modal.accessibility.button_close')}
          onClick={!isUpdating ? handleSGELoginRetry : handleResetSGEAccount}
          className="btnPrimary"
        >
          <div>
            {!isUpdating
              ? t('konnector_modal.button_check_info')
              : t('konnector_modal.button_go')}
          </div>
        </Button>
      </div>
    )
  } else if (error === KonnectorError.USER_ACTION_NEEDED_ACCOUNT_REMOVED) {
    return (
      <Button
        aria-label={t('konnector_modal.accessibility.button_close')}
        onClick={() => {
          window.open(
            `${__SAU_ISSUE_DIRECT_LINK__}?version=${client.appMetadata.version}`
          )
          handleCloseClick(state === SUCCESS_EVENT)
        }}
        className="btnPrimary"
      >
        <div>{t('konnector_modal.button_contact')}</div>
      </Button>
    )
  } else {
    return (
      <Button
        aria-label={t('konnector_modal.accessibility.button_close')}
        onClick={() => handleCloseClick(state === SUCCESS_EVENT)}
        className="btnPrimary"
      >
        <div>{t('konnector_modal.button_validate')}</div>
      </Button>
    )
  }
}

export default KonnectorModalFooter
