import { act, render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import { FluidType } from 'enums'
import React from 'react'
import PartnerIssueModal from './PartnerIssueModal'

const mockHandleClose = jest.fn()
describe('PartnerIssueModal component', () => {
  it('should render correctly', () => {
    const { baseElement } = render(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(screen.getByRole('dialog')).toBeInTheDocument()
    expect(baseElement).toMatchSnapshot()
  })
  it('should render elec modal', () => {
    render(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(
      screen.getByText('consumption.partner_issue_modal.error_connect_elec')
    ).toBeInTheDocument()
  })
  it('should render water modal', () => {
    render(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.WATER}
      />
    )
    expect(
      screen.getByText('consumption.partner_issue_modal.error_connect_water')
    ).toBeInTheDocument()
  })
  it('should close modal', async () => {
    render(
      <PartnerIssueModal
        open={true}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    await act(async () => {
      await userEvent.click(
        screen.getByText('consumption.partner_issue_modal.ok')
      )
    })
    expect(mockHandleClose).toHaveBeenCalled()
  })

  it('should not be rendered', () => {
    render(
      <PartnerIssueModal
        open={false}
        handleCloseClick={mockHandleClose}
        issuedFluid={FluidType.ELECTRICITY}
      />
    )
    expect(screen.queryByRole('dialog')).toBeFalsy()
  })
})
